# About

```{toctree}
---
maxdepth: 3
---

data_workflow_overview
```

## Development

ESSnmx is an open source project by the [European Spallation Source ERIC](https://ess.eu/) (ESS).

## License

ESSnmx is available as open source under the [BSD-3 license](https://opensource.org/license/BSD-3-Clause).

## Citing ESSnmx

Please cite the following:

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14733001.svg)](https://doi.org/10.5281/zenodo.14733001)

To cite a specific version of ESSnmx, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/essnmx/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

ESSnmx is hosted and developed [on GitHub](https://github.com/scipp/essnmx).
